@@ -60,7 +60,23 @@ class FirewallRules(
         :param provisioners: 
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(FirewallRules.__init__)
+            def stub(
+                scope: constructs.Construct,
+                id_: builtins.str,
+                *,
+                firewall_rule: typing.Union[typing.Sequence[typing.Union[FirewallRulesFirewallRule, typing.Dict[str, typing.Any]]], cdktf.IResolvable],
+                server_id: builtins.str,
+                id: typing.Optional[builtins.str] = None,
+                connection: typing.Optional[typing.Union[typing.Union[cdktf.SSHProvisionerConnection, typing.Dict[str, typing.Any]], typing.Union[cdktf.WinrmProvisionerConnection, typing.Dict[str, typing.Any]]]] = None,
+                count: typing.Optional[jsii.Number] = None,
+                depends_on: typing.Optional[typing.Sequence[cdktf.ITerraformDependable]] = None,
+                for_each: typing.Optional[cdktf.ITerraformIterator] = None,
+                lifecycle: typing.Optional[typing.Union[cdktf.TerraformResourceLifecycle, typing.Dict[str, typing.Any]]] = None,
+                provider: typing.Optional[cdktf.TerraformProvider] = None,
+                provisioners: typing.Optional[typing.Sequence[typing.Union[typing.Union[cdktf.FileProvisioner, typing.Dict[str, typing.Any]], typing.Union[cdktf.LocalExecProvisioner, typing.Dict[str, typing.Any]], typing.Union[cdktf.RemoteExecProvisioner, typing.Dict[str, typing.Any]]]]] = None,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
             check_type(argname="argument id_", value=id_, expected_type=type_hints["id_"])
         config = FirewallRulesConfig(
@@ -87,7 +103,11 @@ class FirewallRules(
         :param value: -
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(FirewallRules.put_firewall_rule)
+            def stub(
+                value: typing.Union[typing.Sequence[typing.Union[FirewallRulesFirewallRule, typing.Dict[str, typing.Any]]], cdktf.IResolvable],
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         return typing.cast(None, jsii.invoke(self, "putFirewallRule", [value]))
 
@@ -134,7 +154,9 @@ class FirewallRules(
     @id.setter
     def id(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(FirewallRules, "id").fset)
+            def stub(value: builtins.str) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "id", value)
 
@@ -146,7 +168,9 @@ class FirewallRules(
     @server_id.setter
     def server_id(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(FirewallRules, "server_id").fset)
+            def stub(value: builtins.str) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "serverId", value)
 
@@ -197,7 +221,21 @@ class FirewallRulesConfig(cdktf.TerraformMetaArguments):
         if isinstance(lifecycle, dict):
             lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
         if __debug__:
-            type_hints = typing.get_type_hints(FirewallRulesConfig.__init__)
+            def stub(
+                *,
+                connection: typing.Optional[typing.Union[typing.Union[cdktf.SSHProvisionerConnection, typing.Dict[str, typing.Any]], typing.Union[cdktf.WinrmProvisionerConnection, typing.Dict[str, typing.Any]]]] = None,
+                count: typing.Optional[jsii.Number] = None,
+                depends_on: typing.Optional[typing.Sequence[cdktf.ITerraformDependable]] = None,
+                for_each: typing.Optional[cdktf.ITerraformIterator] = None,
+                lifecycle: typing.Optional[typing.Union[cdktf.TerraformResourceLifecycle, typing.Dict[str, typing.Any]]] = None,
+                provider: typing.Optional[cdktf.TerraformProvider] = None,
+                provisioners: typing.Optional[typing.Sequence[typing.Union[typing.Union[cdktf.FileProvisioner, typing.Dict[str, typing.Any]], typing.Union[cdktf.LocalExecProvisioner, typing.Dict[str, typing.Any]], typing.Union[cdktf.RemoteExecProvisioner, typing.Dict[str, typing.Any]]]]] = None,
+                firewall_rule: typing.Union[typing.Sequence[typing.Union[FirewallRulesFirewallRule, typing.Dict[str, typing.Any]]], cdktf.IResolvable],
+                server_id: builtins.str,
+                id: typing.Optional[builtins.str] = None,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument connection", value=connection, expected_type=type_hints["connection"])
             check_type(argname="argument count", value=count, expected_type=type_hints["count"])
             check_type(argname="argument depends_on", value=depends_on, expected_type=type_hints["depends_on"])
@@ -389,7 +427,25 @@ class FirewallRulesFirewallRule:
         :param source_port_start: The source port range starts from this port number. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/upcloud/r/firewall_rules#source_port_start FirewallRules#source_port_start}
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(FirewallRulesFirewallRule.__init__)
+            def stub(
+                *,
+                action: builtins.str,
+                direction: builtins.str,
+                comment: typing.Optional[builtins.str] = None,
+                destination_address_end: typing.Optional[builtins.str] = None,
+                destination_address_start: typing.Optional[builtins.str] = None,
+                destination_port_end: typing.Optional[builtins.str] = None,
+                destination_port_start: typing.Optional[builtins.str] = None,
+                family: typing.Optional[builtins.str] = None,
+                icmp_type: typing.Optional[builtins.str] = None,
+                protocol: typing.Optional[builtins.str] = None,
+                source_address_end: typing.Optional[builtins.str] = None,
+                source_address_start: typing.Optional[builtins.str] = None,
+                source_port_end: typing.Optional[builtins.str] = None,
+                source_port_start: typing.Optional[builtins.str] = None,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument action", value=action, expected_type=type_hints["action"])
             check_type(argname="argument direction", value=direction, expected_type=type_hints["direction"])
             check_type(argname="argument comment", value=comment, expected_type=type_hints["comment"])
@@ -590,7 +646,13 @@ class FirewallRulesFirewallRuleList(
         :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(FirewallRulesFirewallRuleList.__init__)
+            def stub(
+                terraform_resource: cdktf.IInterpolatingParent,
+                terraform_attribute: builtins.str,
+                wraps_set: builtins.bool,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
             check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
             check_type(argname="argument wraps_set", value=wraps_set, expected_type=type_hints["wraps_set"])
@@ -602,7 +664,9 @@ class FirewallRulesFirewallRuleList(
         :param index: the index of the item to return.
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(FirewallRulesFirewallRuleList.get)
+            def stub(index: jsii.Number) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument index", value=index, expected_type=type_hints["index"])
         return typing.cast("FirewallRulesFirewallRuleOutputReference", jsii.invoke(self, "get", [index]))
 
@@ -615,7 +679,9 @@ class FirewallRulesFirewallRuleList(
     @_terraform_attribute.setter
     def _terraform_attribute(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(FirewallRulesFirewallRuleList, "_terraform_attribute").fset)
+            def stub(value: builtins.str) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "terraformAttribute", value)
 
@@ -628,7 +694,9 @@ class FirewallRulesFirewallRuleList(
     @_terraform_resource.setter
     def _terraform_resource(self, value: cdktf.IInterpolatingParent) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(FirewallRulesFirewallRuleList, "_terraform_resource").fset)
+            def stub(value: cdktf.IInterpolatingParent) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "terraformResource", value)
 
@@ -641,7 +709,9 @@ class FirewallRulesFirewallRuleList(
     @_wraps_set.setter
     def _wraps_set(self, value: builtins.bool) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(FirewallRulesFirewallRuleList, "_wraps_set").fset)
+            def stub(value: builtins.bool) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "wrapsSet", value)
 
@@ -658,7 +728,11 @@ class FirewallRulesFirewallRuleList(
         value: typing.Optional[typing.Union[typing.List[FirewallRulesFirewallRule], cdktf.IResolvable]],
     ) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(FirewallRulesFirewallRuleList, "internal_value").fset)
+            def stub(
+                value: typing.Optional[typing.Union[typing.List[FirewallRulesFirewallRule], cdktf.IResolvable]],
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "internalValue", value)
 
@@ -682,7 +756,14 @@ class FirewallRulesFirewallRuleOutputReference(
         :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(FirewallRulesFirewallRuleOutputReference.__init__)
+            def stub(
+                terraform_resource: cdktf.IInterpolatingParent,
+                terraform_attribute: builtins.str,
+                complex_object_index: jsii.Number,
+                complex_object_is_from_set: builtins.bool,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
             check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
             check_type(argname="argument complex_object_index", value=complex_object_index, expected_type=type_hints["complex_object_index"])
@@ -815,7 +896,9 @@ class FirewallRulesFirewallRuleOutputReference(
     @action.setter
     def action(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(FirewallRulesFirewallRuleOutputReference, "action").fset)
+            def stub(value: builtins.str) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "action", value)
 
@@ -827,7 +910,9 @@ class FirewallRulesFirewallRuleOutputReference(
     @comment.setter
     def comment(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(FirewallRulesFirewallRuleOutputReference, "comment").fset)
+            def stub(value: builtins.str) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "comment", value)
 
@@ -839,7 +924,9 @@ class FirewallRulesFirewallRuleOutputReference(
     @destination_address_end.setter
     def destination_address_end(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(FirewallRulesFirewallRuleOutputReference, "destination_address_end").fset)
+            def stub(value: builtins.str) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "destinationAddressEnd", value)
 
@@ -851,7 +938,9 @@ class FirewallRulesFirewallRuleOutputReference(
     @destination_address_start.setter
     def destination_address_start(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(FirewallRulesFirewallRuleOutputReference, "destination_address_start").fset)
+            def stub(value: builtins.str) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "destinationAddressStart", value)
 
@@ -863,7 +952,9 @@ class FirewallRulesFirewallRuleOutputReference(
     @destination_port_end.setter
     def destination_port_end(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(FirewallRulesFirewallRuleOutputReference, "destination_port_end").fset)
+            def stub(value: builtins.str) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "destinationPortEnd", value)
 
@@ -875,7 +966,9 @@ class FirewallRulesFirewallRuleOutputReference(
     @destination_port_start.setter
     def destination_port_start(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(FirewallRulesFirewallRuleOutputReference, "destination_port_start").fset)
+            def stub(value: builtins.str) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "destinationPortStart", value)
 
@@ -887,7 +980,9 @@ class FirewallRulesFirewallRuleOutputReference(
     @direction.setter
     def direction(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(FirewallRulesFirewallRuleOutputReference, "direction").fset)
+            def stub(value: builtins.str) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "direction", value)
 
@@ -899,7 +994,9 @@ class FirewallRulesFirewallRuleOutputReference(
     @family.setter
     def family(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(FirewallRulesFirewallRuleOutputReference, "family").fset)
+            def stub(value: builtins.str) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "family", value)
 
@@ -911,7 +1008,9 @@ class FirewallRulesFirewallRuleOutputReference(
     @icmp_type.setter
     def icmp_type(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(FirewallRulesFirewallRuleOutputReference, "icmp_type").fset)
+            def stub(value: builtins.str) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "icmpType", value)
 
@@ -923,7 +1022,9 @@ class FirewallRulesFirewallRuleOutputReference(
     @protocol.setter
     def protocol(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(FirewallRulesFirewallRuleOutputReference, "protocol").fset)
+            def stub(value: builtins.str) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "protocol", value)
 
@@ -935,7 +1036,9 @@ class FirewallRulesFirewallRuleOutputReference(
     @source_address_end.setter
     def source_address_end(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(FirewallRulesFirewallRuleOutputReference, "source_address_end").fset)
+            def stub(value: builtins.str) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "sourceAddressEnd", value)
 
@@ -947,7 +1050,9 @@ class FirewallRulesFirewallRuleOutputReference(
     @source_address_start.setter
     def source_address_start(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(FirewallRulesFirewallRuleOutputReference, "source_address_start").fset)
+            def stub(value: builtins.str) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "sourceAddressStart", value)
 
@@ -959,7 +1064,9 @@ class FirewallRulesFirewallRuleOutputReference(
     @source_port_end.setter
     def source_port_end(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(FirewallRulesFirewallRuleOutputReference, "source_port_end").fset)
+            def stub(value: builtins.str) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "sourcePortEnd", value)
 
@@ -971,7 +1078,9 @@ class FirewallRulesFirewallRuleOutputReference(
     @source_port_start.setter
     def source_port_start(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(FirewallRulesFirewallRuleOutputReference, "source_port_start").fset)
+            def stub(value: builtins.str) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "sourcePortStart", value)
 
@@ -988,7 +1097,11 @@ class FirewallRulesFirewallRuleOutputReference(
         value: typing.Optional[typing.Union[FirewallRulesFirewallRule, cdktf.IResolvable]],
     ) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(FirewallRulesFirewallRuleOutputReference, "internal_value").fset)
+            def stub(
+                value: typing.Optional[typing.Union[FirewallRulesFirewallRule, cdktf.IResolvable]],
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "internalValue", value)
 
