@@ -64,7 +64,25 @@ class LoadbalancerBackend(
         :param provisioners: 
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(LoadbalancerBackend.__init__)
+            def stub(
+                scope: constructs.Construct,
+                id_: builtins.str,
+                *,
+                loadbalancer: builtins.str,
+                name: builtins.str,
+                id: typing.Optional[builtins.str] = None,
+                properties: typing.Optional[typing.Union[LoadbalancerBackendProperties, typing.Dict[str, typing.Any]]] = None,
+                resolver_name: typing.Optional[builtins.str] = None,
+                connection: typing.Optional[typing.Union[typing.Union[cdktf.SSHProvisionerConnection, typing.Dict[str, typing.Any]], typing.Union[cdktf.WinrmProvisionerConnection, typing.Dict[str, typing.Any]]]] = None,
+                count: typing.Optional[jsii.Number] = None,
+                depends_on: typing.Optional[typing.Sequence[cdktf.ITerraformDependable]] = None,
+                for_each: typing.Optional[cdktf.ITerraformIterator] = None,
+                lifecycle: typing.Optional[typing.Union[cdktf.TerraformResourceLifecycle, typing.Dict[str, typing.Any]]] = None,
+                provider: typing.Optional[cdktf.TerraformProvider] = None,
+                provisioners: typing.Optional[typing.Sequence[typing.Union[typing.Union[cdktf.FileProvisioner, typing.Dict[str, typing.Any]], typing.Union[cdktf.LocalExecProvisioner, typing.Dict[str, typing.Any]], typing.Union[cdktf.RemoteExecProvisioner, typing.Dict[str, typing.Any]]]]] = None,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
             check_type(argname="argument id_", value=id_, expected_type=type_hints["id_"])
         config = LoadbalancerBackendConfig(
@@ -190,7 +208,9 @@ class LoadbalancerBackend(
     @id.setter
     def id(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(LoadbalancerBackend, "id").fset)
+            def stub(value: builtins.str) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "id", value)
 
@@ -202,7 +222,9 @@ class LoadbalancerBackend(
     @loadbalancer.setter
     def loadbalancer(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(LoadbalancerBackend, "loadbalancer").fset)
+            def stub(value: builtins.str) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "loadbalancer", value)
 
@@ -214,7 +236,9 @@ class LoadbalancerBackend(
     @name.setter
     def name(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(LoadbalancerBackend, "name").fset)
+            def stub(value: builtins.str) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "name", value)
 
@@ -226,7 +250,9 @@ class LoadbalancerBackend(
     @resolver_name.setter
     def resolver_name(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(LoadbalancerBackend, "resolver_name").fset)
+            def stub(value: builtins.str) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "resolverName", value)
 
@@ -285,7 +311,23 @@ class LoadbalancerBackendConfig(cdktf.TerraformMetaArguments):
         if isinstance(properties, dict):
             properties = LoadbalancerBackendProperties(**properties)
         if __debug__:
-            type_hints = typing.get_type_hints(LoadbalancerBackendConfig.__init__)
+            def stub(
+                *,
+                connection: typing.Optional[typing.Union[typing.Union[cdktf.SSHProvisionerConnection, typing.Dict[str, typing.Any]], typing.Union[cdktf.WinrmProvisionerConnection, typing.Dict[str, typing.Any]]]] = None,
+                count: typing.Optional[jsii.Number] = None,
+                depends_on: typing.Optional[typing.Sequence[cdktf.ITerraformDependable]] = None,
+                for_each: typing.Optional[cdktf.ITerraformIterator] = None,
+                lifecycle: typing.Optional[typing.Union[cdktf.TerraformResourceLifecycle, typing.Dict[str, typing.Any]]] = None,
+                provider: typing.Optional[cdktf.TerraformProvider] = None,
+                provisioners: typing.Optional[typing.Sequence[typing.Union[typing.Union[cdktf.FileProvisioner, typing.Dict[str, typing.Any]], typing.Union[cdktf.LocalExecProvisioner, typing.Dict[str, typing.Any]], typing.Union[cdktf.RemoteExecProvisioner, typing.Dict[str, typing.Any]]]]] = None,
+                loadbalancer: builtins.str,
+                name: builtins.str,
+                id: typing.Optional[builtins.str] = None,
+                properties: typing.Optional[typing.Union[LoadbalancerBackendProperties, typing.Dict[str, typing.Any]]] = None,
+                resolver_name: typing.Optional[builtins.str] = None,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument connection", value=connection, expected_type=type_hints["connection"])
             check_type(argname="argument count", value=count, expected_type=type_hints["count"])
             check_type(argname="argument depends_on", value=depends_on, expected_type=type_hints["depends_on"])
@@ -487,7 +529,21 @@ class LoadbalancerBackendProperties:
         :param timeout_tunnel: Maximum inactivity time on the client and server side for tunnels in seconds. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/upcloud/r/loadbalancer_backend#timeout_tunnel LoadbalancerBackend#timeout_tunnel}
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(LoadbalancerBackendProperties.__init__)
+            def stub(
+                *,
+                health_check_expected_status: typing.Optional[jsii.Number] = None,
+                health_check_fall: typing.Optional[jsii.Number] = None,
+                health_check_interval: typing.Optional[jsii.Number] = None,
+                health_check_rise: typing.Optional[jsii.Number] = None,
+                health_check_type: typing.Optional[builtins.str] = None,
+                health_check_url: typing.Optional[builtins.str] = None,
+                outbound_proxy_protocol: typing.Optional[builtins.str] = None,
+                sticky_session_cookie_name: typing.Optional[builtins.str] = None,
+                timeout_server: typing.Optional[jsii.Number] = None,
+                timeout_tunnel: typing.Optional[jsii.Number] = None,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument health_check_expected_status", value=health_check_expected_status, expected_type=type_hints["health_check_expected_status"])
             check_type(argname="argument health_check_fall", value=health_check_fall, expected_type=type_hints["health_check_fall"])
             check_type(argname="argument health_check_interval", value=health_check_interval, expected_type=type_hints["health_check_interval"])
@@ -637,7 +693,12 @@ class LoadbalancerBackendPropertiesOutputReference(
         :param terraform_attribute: The attribute on the parent resource this class is referencing.
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(LoadbalancerBackendPropertiesOutputReference.__init__)
+            def stub(
+                terraform_resource: cdktf.IInterpolatingParent,
+                terraform_attribute: builtins.str,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
             check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
         jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])
@@ -740,7 +801,9 @@ class LoadbalancerBackendPropertiesOutputReference(
     @health_check_expected_status.setter
     def health_check_expected_status(self, value: jsii.Number) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(LoadbalancerBackendPropertiesOutputReference, "health_check_expected_status").fset)
+            def stub(value: jsii.Number) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "healthCheckExpectedStatus", value)
 
@@ -752,7 +815,9 @@ class LoadbalancerBackendPropertiesOutputReference(
     @health_check_fall.setter
     def health_check_fall(self, value: jsii.Number) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(LoadbalancerBackendPropertiesOutputReference, "health_check_fall").fset)
+            def stub(value: jsii.Number) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "healthCheckFall", value)
 
@@ -764,7 +829,9 @@ class LoadbalancerBackendPropertiesOutputReference(
     @health_check_interval.setter
     def health_check_interval(self, value: jsii.Number) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(LoadbalancerBackendPropertiesOutputReference, "health_check_interval").fset)
+            def stub(value: jsii.Number) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "healthCheckInterval", value)
 
@@ -776,7 +843,9 @@ class LoadbalancerBackendPropertiesOutputReference(
     @health_check_rise.setter
     def health_check_rise(self, value: jsii.Number) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(LoadbalancerBackendPropertiesOutputReference, "health_check_rise").fset)
+            def stub(value: jsii.Number) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "healthCheckRise", value)
 
@@ -788,7 +857,9 @@ class LoadbalancerBackendPropertiesOutputReference(
     @health_check_type.setter
     def health_check_type(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(LoadbalancerBackendPropertiesOutputReference, "health_check_type").fset)
+            def stub(value: builtins.str) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "healthCheckType", value)
 
@@ -800,7 +871,9 @@ class LoadbalancerBackendPropertiesOutputReference(
     @health_check_url.setter
     def health_check_url(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(LoadbalancerBackendPropertiesOutputReference, "health_check_url").fset)
+            def stub(value: builtins.str) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "healthCheckUrl", value)
 
@@ -812,7 +885,9 @@ class LoadbalancerBackendPropertiesOutputReference(
     @outbound_proxy_protocol.setter
     def outbound_proxy_protocol(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(LoadbalancerBackendPropertiesOutputReference, "outbound_proxy_protocol").fset)
+            def stub(value: builtins.str) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "outboundProxyProtocol", value)
 
@@ -824,7 +899,9 @@ class LoadbalancerBackendPropertiesOutputReference(
     @sticky_session_cookie_name.setter
     def sticky_session_cookie_name(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(LoadbalancerBackendPropertiesOutputReference, "sticky_session_cookie_name").fset)
+            def stub(value: builtins.str) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "stickySessionCookieName", value)
 
@@ -836,7 +913,9 @@ class LoadbalancerBackendPropertiesOutputReference(
     @timeout_server.setter
     def timeout_server(self, value: jsii.Number) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(LoadbalancerBackendPropertiesOutputReference, "timeout_server").fset)
+            def stub(value: jsii.Number) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "timeoutServer", value)
 
@@ -848,7 +927,9 @@ class LoadbalancerBackendPropertiesOutputReference(
     @timeout_tunnel.setter
     def timeout_tunnel(self, value: jsii.Number) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(LoadbalancerBackendPropertiesOutputReference, "timeout_tunnel").fset)
+            def stub(value: jsii.Number) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "timeoutTunnel", value)
 
@@ -863,7 +944,9 @@ class LoadbalancerBackendPropertiesOutputReference(
         value: typing.Optional[LoadbalancerBackendProperties],
     ) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(LoadbalancerBackendPropertiesOutputReference, "internal_value").fset)
+            def stub(value: typing.Optional[LoadbalancerBackendProperties]) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "internalValue", value)
 
