@@ -62,7 +62,24 @@ class LoadbalancerDynamicCertificateBundle(
         :param provisioners: 
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(LoadbalancerDynamicCertificateBundle.__init__)
+            def stub(
+                scope: constructs.Construct,
+                id_: builtins.str,
+                *,
+                hostnames: typing.Sequence[builtins.str],
+                key_type: builtins.str,
+                name: builtins.str,
+                id: typing.Optional[builtins.str] = None,
+                connection: typing.Optional[typing.Union[typing.Union[cdktf.SSHProvisionerConnection, typing.Dict[str, typing.Any]], typing.Union[cdktf.WinrmProvisionerConnection, typing.Dict[str, typing.Any]]]] = None,
+                count: typing.Optional[jsii.Number] = None,
+                depends_on: typing.Optional[typing.Sequence[cdktf.ITerraformDependable]] = None,
+                for_each: typing.Optional[cdktf.ITerraformIterator] = None,
+                lifecycle: typing.Optional[typing.Union[cdktf.TerraformResourceLifecycle, typing.Dict[str, typing.Any]]] = None,
+                provider: typing.Optional[cdktf.TerraformProvider] = None,
+                provisioners: typing.Optional[typing.Sequence[typing.Union[typing.Union[cdktf.FileProvisioner, typing.Dict[str, typing.Any]], typing.Union[cdktf.LocalExecProvisioner, typing.Dict[str, typing.Any]], typing.Union[cdktf.RemoteExecProvisioner, typing.Dict[str, typing.Any]]]]] = None,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
             check_type(argname="argument id_", value=id_, expected_type=type_hints["id_"])
         config = LoadbalancerDynamicCertificateBundleConfig(
@@ -137,7 +154,9 @@ class LoadbalancerDynamicCertificateBundle(
     @hostnames.setter
     def hostnames(self, value: typing.List[builtins.str]) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(LoadbalancerDynamicCertificateBundle, "hostnames").fset)
+            def stub(value: typing.List[builtins.str]) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "hostnames", value)
 
@@ -149,7 +168,9 @@ class LoadbalancerDynamicCertificateBundle(
     @id.setter
     def id(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(LoadbalancerDynamicCertificateBundle, "id").fset)
+            def stub(value: builtins.str) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "id", value)
 
@@ -161,7 +182,9 @@ class LoadbalancerDynamicCertificateBundle(
     @key_type.setter
     def key_type(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(LoadbalancerDynamicCertificateBundle, "key_type").fset)
+            def stub(value: builtins.str) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "keyType", value)
 
@@ -173,7 +196,9 @@ class LoadbalancerDynamicCertificateBundle(
     @name.setter
     def name(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(LoadbalancerDynamicCertificateBundle, "name").fset)
+            def stub(value: builtins.str) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "name", value)
 
@@ -227,7 +252,22 @@ class LoadbalancerDynamicCertificateBundleConfig(cdktf.TerraformMetaArguments):
         if isinstance(lifecycle, dict):
             lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
         if __debug__:
-            type_hints = typing.get_type_hints(LoadbalancerDynamicCertificateBundleConfig.__init__)
+            def stub(
+                *,
+                connection: typing.Optional[typing.Union[typing.Union[cdktf.SSHProvisionerConnection, typing.Dict[str, typing.Any]], typing.Union[cdktf.WinrmProvisionerConnection, typing.Dict[str, typing.Any]]]] = None,
+                count: typing.Optional[jsii.Number] = None,
+                depends_on: typing.Optional[typing.Sequence[cdktf.ITerraformDependable]] = None,
+                for_each: typing.Optional[cdktf.ITerraformIterator] = None,
+                lifecycle: typing.Optional[typing.Union[cdktf.TerraformResourceLifecycle, typing.Dict[str, typing.Any]]] = None,
+                provider: typing.Optional[cdktf.TerraformProvider] = None,
+                provisioners: typing.Optional[typing.Sequence[typing.Union[typing.Union[cdktf.FileProvisioner, typing.Dict[str, typing.Any]], typing.Union[cdktf.LocalExecProvisioner, typing.Dict[str, typing.Any]], typing.Union[cdktf.RemoteExecProvisioner, typing.Dict[str, typing.Any]]]]] = None,
+                hostnames: typing.Sequence[builtins.str],
+                key_type: builtins.str,
+                name: builtins.str,
+                id: typing.Optional[builtins.str] = None,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument connection", value=connection, expected_type=type_hints["connection"])
             check_type(argname="argument count", value=count, expected_type=type_hints["count"])
             check_type(argname="argument depends_on", value=depends_on, expected_type=type_hints["depends_on"])
