@@ -39,6 +39,7 @@ class LoadbalancerFrontend(
         name: builtins.str,
         port: jsii.Number,
         id: typing.Optional[builtins.str] = None,
+        networks: typing.Optional[typing.Union[cdktf.IResolvable, typing.Sequence[typing.Union["LoadbalancerFrontendNetworks", typing.Dict[str, typing.Any]]]]] = None,
         properties: typing.Optional[typing.Union["LoadbalancerFrontendProperties", typing.Dict[str, typing.Any]]] = None,
         connection: typing.Optional[typing.Union[typing.Union[cdktf.SSHProvisionerConnection, typing.Dict[str, typing.Any]], typing.Union[cdktf.WinrmProvisionerConnection, typing.Dict[str, typing.Any]]]] = None,
         count: typing.Optional[jsii.Number] = None,
@@ -58,6 +59,7 @@ class LoadbalancerFrontend(
         :param name: The name of the frontend must be unique within the load balancer service. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/upcloud/r/loadbalancer_frontend#name LoadbalancerFrontend#name}
         :param port: Port to listen incoming requests. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/upcloud/r/loadbalancer_frontend#port LoadbalancerFrontend#port}
         :param id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/upcloud/r/loadbalancer_frontend#id LoadbalancerFrontend#id}. Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2. If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
+        :param networks: networks block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/upcloud/r/loadbalancer_frontend#networks LoadbalancerFrontend#networks}
         :param properties: properties block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/upcloud/r/loadbalancer_frontend#properties LoadbalancerFrontend#properties}
         :param connection: 
         :param count: 
@@ -68,7 +70,28 @@ class LoadbalancerFrontend(
         :param provisioners: 
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(LoadbalancerFrontend.__init__)
+            def stub(
+                scope: constructs.Construct,
+                id_: builtins.str,
+                *,
+                default_backend_name: builtins.str,
+                loadbalancer: builtins.str,
+                mode: builtins.str,
+                name: builtins.str,
+                port: jsii.Number,
+                id: typing.Optional[builtins.str] = None,
+                networks: typing.Optional[typing.Union[cdktf.IResolvable, typing.Sequence[typing.Union[LoadbalancerFrontendNetworks, typing.Dict[str, typing.Any]]]]] = None,
+                properties: typing.Optional[typing.Union[LoadbalancerFrontendProperties, typing.Dict[str, typing.Any]]] = None,
+                connection: typing.Optional[typing.Union[typing.Union[cdktf.SSHProvisionerConnection, typing.Dict[str, typing.Any]], typing.Union[cdktf.WinrmProvisionerConnection, typing.Dict[str, typing.Any]]]] = None,
+                count: typing.Optional[jsii.Number] = None,
+                depends_on: typing.Optional[typing.Sequence[cdktf.ITerraformDependable]] = None,
+                for_each: typing.Optional[cdktf.ITerraformIterator] = None,
+                lifecycle: typing.Optional[typing.Union[cdktf.TerraformResourceLifecycle, typing.Dict[str, typing.Any]]] = None,
+                provider: typing.Optional[cdktf.TerraformProvider] = None,
+                provisioners: typing.Optional[typing.Sequence[typing.Union[typing.Union[cdktf.FileProvisioner, typing.Dict[str, typing.Any]], typing.Union[cdktf.LocalExecProvisioner, typing.Dict[str, typing.Any]], typing.Union[cdktf.RemoteExecProvisioner, typing.Dict[str, typing.Any]]]]] = None,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
             check_type(argname="argument id_", value=id_, expected_type=type_hints["id_"])
         config = LoadbalancerFrontendConfig(
@@ -78,6 +101,7 @@ class LoadbalancerFrontend(
             name=name,
             port=port,
             id=id,
+            networks=networks,
             properties=properties,
             connection=connection,
             count=count,
@@ -90,6 +114,23 @@ class LoadbalancerFrontend(
 
         jsii.create(self.__class__, self, [scope, id_, config])
 
+    @jsii.member(jsii_name="putNetworks")
+    def put_networks(
+        self,
+        value: typing.Union[cdktf.IResolvable, typing.Sequence[typing.Union["LoadbalancerFrontendNetworks", typing.Dict[str, typing.Any]]]],
+    ) -> None:
+        '''
+        :param value: -
+        '''
+        if __debug__:
+            def stub(
+                value: typing.Union[cdktf.IResolvable, typing.Sequence[typing.Union[LoadbalancerFrontendNetworks, typing.Dict[str, typing.Any]]]],
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
+            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
+        return typing.cast(None, jsii.invoke(self, "putNetworks", [value]))
+
     @jsii.member(jsii_name="putProperties")
     def put_properties(
         self,
@@ -112,6 +153,10 @@ class LoadbalancerFrontend(
     def reset_id(self) -> None:
         return typing.cast(None, jsii.invoke(self, "resetId", []))
 
+    @jsii.member(jsii_name="resetNetworks")
+    def reset_networks(self) -> None:
+        return typing.cast(None, jsii.invoke(self, "resetNetworks", []))
+
     @jsii.member(jsii_name="resetProperties")
     def reset_properties(self) -> None:
         return typing.cast(None, jsii.invoke(self, "resetProperties", []))
@@ -125,6 +170,11 @@ class LoadbalancerFrontend(
     def TF_RESOURCE_TYPE(cls) -> builtins.str:
         return typing.cast(builtins.str, jsii.sget(cls, "tfResourceType"))
 
+    @builtins.property
+    @jsii.member(jsii_name="networks")
+    def networks(self) -> "LoadbalancerFrontendNetworksList":
+        return typing.cast("LoadbalancerFrontendNetworksList", jsii.get(self, "networks"))
+
     @builtins.property
     @jsii.member(jsii_name="properties")
     def properties(self) -> "LoadbalancerFrontendPropertiesOutputReference":
@@ -165,6 +215,13 @@ class LoadbalancerFrontend(
     def name_input(self) -> typing.Optional[builtins.str]:
         return typing.cast(typing.Optional[builtins.str], jsii.get(self, "nameInput"))
 
+    @builtins.property
+    @jsii.member(jsii_name="networksInput")
+    def networks_input(
+        self,
+    ) -> typing.Optional[typing.Union[cdktf.IResolvable, typing.List["LoadbalancerFrontendNetworks"]]]:
+        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, typing.List["LoadbalancerFrontendNetworks"]]], jsii.get(self, "networksInput"))
+
     @builtins.property
     @jsii.member(jsii_name="portInput")
     def port_input(self) -> typing.Optional[jsii.Number]:
@@ -183,7 +240,9 @@ class LoadbalancerFrontend(
     @default_backend_name.setter
     def default_backend_name(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(LoadbalancerFrontend, "default_backend_name").fset)
+            def stub(value: builtins.str) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "defaultBackendName", value)
 
@@ -195,7 +254,9 @@ class LoadbalancerFrontend(
     @id.setter
     def id(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(LoadbalancerFrontend, "id").fset)
+            def stub(value: builtins.str) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "id", value)
 
@@ -207,7 +268,9 @@ class LoadbalancerFrontend(
     @loadbalancer.setter
     def loadbalancer(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(LoadbalancerFrontend, "loadbalancer").fset)
+            def stub(value: builtins.str) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "loadbalancer", value)
 
@@ -219,7 +282,9 @@ class LoadbalancerFrontend(
     @mode.setter
     def mode(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(LoadbalancerFrontend, "mode").fset)
+            def stub(value: builtins.str) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "mode", value)
 
@@ -231,7 +296,9 @@ class LoadbalancerFrontend(
     @name.setter
     def name(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(LoadbalancerFrontend, "name").fset)
+            def stub(value: builtins.str) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "name", value)
 
@@ -243,7 +310,9 @@ class LoadbalancerFrontend(
     @port.setter
     def port(self, value: jsii.Number) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(LoadbalancerFrontend, "port").fset)
+            def stub(value: jsii.Number) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "port", value)
 
@@ -265,6 +334,7 @@ class LoadbalancerFrontend(
         "name": "name",
         "port": "port",
         "id": "id",
+        "networks": "networks",
         "properties": "properties",
     },
 )
@@ -285,6 +355,7 @@ class LoadbalancerFrontendConfig(cdktf.TerraformMetaArguments):
         name: builtins.str,
         port: jsii.Number,
         id: typing.Optional[builtins.str] = None,
+        networks: typing.Optional[typing.Union[cdktf.IResolvable, typing.Sequence[typing.Union["LoadbalancerFrontendNetworks", typing.Dict[str, typing.Any]]]]] = None,
         properties: typing.Optional[typing.Union["LoadbalancerFrontendProperties", typing.Dict[str, typing.Any]]] = None,
     ) -> None:
         '''
@@ -301,6 +372,7 @@ class LoadbalancerFrontendConfig(cdktf.TerraformMetaArguments):
         :param name: The name of the frontend must be unique within the load balancer service. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/upcloud/r/loadbalancer_frontend#name LoadbalancerFrontend#name}
         :param port: Port to listen incoming requests. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/upcloud/r/loadbalancer_frontend#port LoadbalancerFrontend#port}
         :param id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/upcloud/r/loadbalancer_frontend#id LoadbalancerFrontend#id}. Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2. If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
+        :param networks: networks block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/upcloud/r/loadbalancer_frontend#networks LoadbalancerFrontend#networks}
         :param properties: properties block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/upcloud/r/loadbalancer_frontend#properties LoadbalancerFrontend#properties}
         '''
         if isinstance(lifecycle, dict):
@@ -308,7 +380,26 @@ class LoadbalancerFrontendConfig(cdktf.TerraformMetaArguments):
         if isinstance(properties, dict):
             properties = LoadbalancerFrontendProperties(**properties)
         if __debug__:
-            type_hints = typing.get_type_hints(LoadbalancerFrontendConfig.__init__)
+            def stub(
+                *,
+                connection: typing.Optional[typing.Union[typing.Union[cdktf.SSHProvisionerConnection, typing.Dict[str, typing.Any]], typing.Union[cdktf.WinrmProvisionerConnection, typing.Dict[str, typing.Any]]]] = None,
+                count: typing.Optional[jsii.Number] = None,
+                depends_on: typing.Optional[typing.Sequence[cdktf.ITerraformDependable]] = None,
+                for_each: typing.Optional[cdktf.ITerraformIterator] = None,
+                lifecycle: typing.Optional[typing.Union[cdktf.TerraformResourceLifecycle, typing.Dict[str, typing.Any]]] = None,
+                provider: typing.Optional[cdktf.TerraformProvider] = None,
+                provisioners: typing.Optional[typing.Sequence[typing.Union[typing.Union[cdktf.FileProvisioner, typing.Dict[str, typing.Any]], typing.Union[cdktf.LocalExecProvisioner, typing.Dict[str, typing.Any]], typing.Union[cdktf.RemoteExecProvisioner, typing.Dict[str, typing.Any]]]]] = None,
+                default_backend_name: builtins.str,
+                loadbalancer: builtins.str,
+                mode: builtins.str,
+                name: builtins.str,
+                port: jsii.Number,
+                id: typing.Optional[builtins.str] = None,
+                networks: typing.Optional[typing.Union[cdktf.IResolvable, typing.Sequence[typing.Union[LoadbalancerFrontendNetworks, typing.Dict[str, typing.Any]]]]] = None,
+                properties: typing.Optional[typing.Union[LoadbalancerFrontendProperties, typing.Dict[str, typing.Any]]] = None,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument connection", value=connection, expected_type=type_hints["connection"])
             check_type(argname="argument count", value=count, expected_type=type_hints["count"])
             check_type(argname="argument depends_on", value=depends_on, expected_type=type_hints["depends_on"])
@@ -322,6 +413,7 @@ class LoadbalancerFrontendConfig(cdktf.TerraformMetaArguments):
             check_type(argname="argument name", value=name, expected_type=type_hints["name"])
             check_type(argname="argument port", value=port, expected_type=type_hints["port"])
             check_type(argname="argument id", value=id, expected_type=type_hints["id"])
+            check_type(argname="argument networks", value=networks, expected_type=type_hints["networks"])
             check_type(argname="argument properties", value=properties, expected_type=type_hints["properties"])
         self._values: typing.Dict[str, typing.Any] = {
             "default_backend_name": default_backend_name,
@@ -346,6 +438,8 @@ class LoadbalancerFrontendConfig(cdktf.TerraformMetaArguments):
             self._values["provisioners"] = provisioners
         if id is not None:
             self._values["id"] = id
+        if networks is not None:
+            self._values["networks"] = networks
         if properties is not None:
             self._values["properties"] = properties
 
@@ -473,6 +567,17 @@ class LoadbalancerFrontendConfig(cdktf.TerraformMetaArguments):
         result = self._values.get("id")
         return typing.cast(typing.Optional[builtins.str], result)
 
+    @builtins.property
+    def networks(
+        self,
+    ) -> typing.Optional[typing.Union[cdktf.IResolvable, typing.List["LoadbalancerFrontendNetworks"]]]:
+        '''networks block.
+
+        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/upcloud/r/loadbalancer_frontend#networks LoadbalancerFrontend#networks}
+        '''
+        result = self._values.get("networks")
+        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, typing.List["LoadbalancerFrontendNetworks"]]], result)
+
     @builtins.property
     def properties(self) -> typing.Optional["LoadbalancerFrontendProperties"]:
         '''properties block.
@@ -494,6 +599,229 @@ class LoadbalancerFrontendConfig(cdktf.TerraformMetaArguments):
         )
 
 
+@jsii.data_type(
+    jsii_type="@cdktf/provider-upcloud.loadbalancerFrontend.LoadbalancerFrontendNetworks",
+    jsii_struct_bases=[],
+    name_mapping={"name": "name"},
+)
+class LoadbalancerFrontendNetworks:
+    def __init__(self, *, name: builtins.str) -> None:
+        '''
+        :param name: Name of the load balancer network. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/upcloud/r/loadbalancer_frontend#name LoadbalancerFrontend#name}
+        '''
+        if __debug__:
+            def stub(*, name: builtins.str) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
+            check_type(argname="argument name", value=name, expected_type=type_hints["name"])
+        self._values: typing.Dict[str, typing.Any] = {
+            "name": name,
+        }
+
+    @builtins.property
+    def name(self) -> builtins.str:
+        '''Name of the load balancer network.
+
+        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/upcloud/r/loadbalancer_frontend#name LoadbalancerFrontend#name}
+        '''
+        result = self._values.get("name")
+        assert result is not None, "Required property 'name' is missing"
+        return typing.cast(builtins.str, result)
+
+    def __eq__(self, rhs: typing.Any) -> builtins.bool:
+        return isinstance(rhs, self.__class__) and rhs._values == self._values
+
+    def __ne__(self, rhs: typing.Any) -> builtins.bool:
+        return not (rhs == self)
+
+    def __repr__(self) -> str:
+        return "LoadbalancerFrontendNetworks(%s)" % ", ".join(
+            k + "=" + repr(v) for k, v in self._values.items()
+        )
+
+
+class LoadbalancerFrontendNetworksList(
+    cdktf.ComplexList,
+    metaclass=jsii.JSIIMeta,
+    jsii_type="@cdktf/provider-upcloud.loadbalancerFrontend.LoadbalancerFrontendNetworksList",
+):
+    def __init__(
+        self,
+        terraform_resource: cdktf.IInterpolatingParent,
+        terraform_attribute: builtins.str,
+        wraps_set: builtins.bool,
+    ) -> None:
+        '''
+        :param terraform_resource: The parent resource.
+        :param terraform_attribute: The attribute on the parent resource this class is referencing.
+        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
+        '''
+        if __debug__:
+            def stub(
+                terraform_resource: cdktf.IInterpolatingParent,
+                terraform_attribute: builtins.str,
+                wraps_set: builtins.bool,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
+            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
+            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
+            check_type(argname="argument wraps_set", value=wraps_set, expected_type=type_hints["wraps_set"])
+        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])
+
+    @jsii.member(jsii_name="get")
+    def get(self, index: jsii.Number) -> "LoadbalancerFrontendNetworksOutputReference":
+        '''
+        :param index: the index of the item to return.
+        '''
+        if __debug__:
+            def stub(index: jsii.Number) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
+            check_type(argname="argument index", value=index, expected_type=type_hints["index"])
+        return typing.cast("LoadbalancerFrontendNetworksOutputReference", jsii.invoke(self, "get", [index]))
+
+    @builtins.property
+    @jsii.member(jsii_name="terraformAttribute")
+    def _terraform_attribute(self) -> builtins.str:
+        '''The attribute on the parent resource this class is referencing.'''
+        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))
+
+    @_terraform_attribute.setter
+    def _terraform_attribute(self, value: builtins.str) -> None:
+        if __debug__:
+            def stub(value: builtins.str) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
+            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
+        jsii.set(self, "terraformAttribute", value)
+
+    @builtins.property
+    @jsii.member(jsii_name="terraformResource")
+    def _terraform_resource(self) -> cdktf.IInterpolatingParent:
+        '''The parent resource.'''
+        return typing.cast(cdktf.IInterpolatingParent, jsii.get(self, "terraformResource"))
+
+    @_terraform_resource.setter
+    def _terraform_resource(self, value: cdktf.IInterpolatingParent) -> None:
+        if __debug__:
+            def stub(value: cdktf.IInterpolatingParent) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
+            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
+        jsii.set(self, "terraformResource", value)
+
+    @builtins.property
+    @jsii.member(jsii_name="wrapsSet")
+    def _wraps_set(self) -> builtins.bool:
+        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
+        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))
+
+    @_wraps_set.setter
+    def _wraps_set(self, value: builtins.bool) -> None:
+        if __debug__:
+            def stub(value: builtins.bool) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
+            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
+        jsii.set(self, "wrapsSet", value)
+
+    @builtins.property
+    @jsii.member(jsii_name="internalValue")
+    def internal_value(
+        self,
+    ) -> typing.Optional[typing.Union[cdktf.IResolvable, typing.List[LoadbalancerFrontendNetworks]]]:
+        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, typing.List[LoadbalancerFrontendNetworks]]], jsii.get(self, "internalValue"))
+
+    @internal_value.setter
+    def internal_value(
+        self,
+        value: typing.Optional[typing.Union[cdktf.IResolvable, typing.List[LoadbalancerFrontendNetworks]]],
+    ) -> None:
+        if __debug__:
+            def stub(
+                value: typing.Optional[typing.Union[cdktf.IResolvable, typing.List[LoadbalancerFrontendNetworks]]],
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
+            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
+        jsii.set(self, "internalValue", value)
+
+
+class LoadbalancerFrontendNetworksOutputReference(
+    cdktf.ComplexObject,
+    metaclass=jsii.JSIIMeta,
+    jsii_type="@cdktf/provider-upcloud.loadbalancerFrontend.LoadbalancerFrontendNetworksOutputReference",
+):
+    def __init__(
+        self,
+        terraform_resource: cdktf.IInterpolatingParent,
+        terraform_attribute: builtins.str,
+        complex_object_index: jsii.Number,
+        complex_object_is_from_set: builtins.bool,
+    ) -> None:
+        '''
+        :param terraform_resource: The parent resource.
+        :param terraform_attribute: The attribute on the parent resource this class is referencing.
+        :param complex_object_index: the index of this item in the list.
+        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
+        '''
+        if __debug__:
+            def stub(
+                terraform_resource: cdktf.IInterpolatingParent,
+                terraform_attribute: builtins.str,
+                complex_object_index: jsii.Number,
+                complex_object_is_from_set: builtins.bool,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
+            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
+            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
+            check_type(argname="argument complex_object_index", value=complex_object_index, expected_type=type_hints["complex_object_index"])
+            check_type(argname="argument complex_object_is_from_set", value=complex_object_is_from_set, expected_type=type_hints["complex_object_is_from_set"])
+        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])
+
+    @builtins.property
+    @jsii.member(jsii_name="nameInput")
+    def name_input(self) -> typing.Optional[builtins.str]:
+        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "nameInput"))
+
+    @builtins.property
+    @jsii.member(jsii_name="name")
+    def name(self) -> builtins.str:
+        return typing.cast(builtins.str, jsii.get(self, "name"))
+
+    @name.setter
+    def name(self, value: builtins.str) -> None:
+        if __debug__:
+            def stub(value: builtins.str) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
+            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
+        jsii.set(self, "name", value)
+
+    @builtins.property
+    @jsii.member(jsii_name="internalValue")
+    def internal_value(
+        self,
+    ) -> typing.Optional[typing.Union[LoadbalancerFrontendNetworks, cdktf.IResolvable]]:
+        return typing.cast(typing.Optional[typing.Union[LoadbalancerFrontendNetworks, cdktf.IResolvable]], jsii.get(self, "internalValue"))
+
+    @internal_value.setter
+    def internal_value(
+        self,
+        value: typing.Optional[typing.Union[LoadbalancerFrontendNetworks, cdktf.IResolvable]],
+    ) -> None:
+        if __debug__:
+            def stub(
+                value: typing.Optional[typing.Union[LoadbalancerFrontendNetworks, cdktf.IResolvable]],
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
+            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
+        jsii.set(self, "internalValue", value)
+
+
 @jsii.data_type(
     jsii_type="@cdktf/provider-upcloud.loadbalancerFrontend.LoadbalancerFrontendProperties",
     jsii_struct_bases=[],
@@ -514,7 +842,13 @@ class LoadbalancerFrontendProperties:
         :param timeout_client: Client request timeout in seconds. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/upcloud/r/loadbalancer_frontend#timeout_client LoadbalancerFrontend#timeout_client}
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(LoadbalancerFrontendProperties.__init__)
+            def stub(
+                *,
+                inbound_proxy_protocol: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
+                timeout_client: typing.Optional[jsii.Number] = None,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument inbound_proxy_protocol", value=inbound_proxy_protocol, expected_type=type_hints["inbound_proxy_protocol"])
             check_type(argname="argument timeout_client", value=timeout_client, expected_type=type_hints["timeout_client"])
         self._values: typing.Dict[str, typing.Any] = {}
@@ -570,7 +904,12 @@ class LoadbalancerFrontendPropertiesOutputReference(
         :param terraform_attribute: The attribute on the parent resource this class is referencing.
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(LoadbalancerFrontendPropertiesOutputReference.__init__)
+            def stub(
+                terraform_resource: cdktf.IInterpolatingParent,
+                terraform_attribute: builtins.str,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
             check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
         jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])
@@ -606,7 +945,9 @@ class LoadbalancerFrontendPropertiesOutputReference(
         value: typing.Union[builtins.bool, cdktf.IResolvable],
     ) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(LoadbalancerFrontendPropertiesOutputReference, "inbound_proxy_protocol").fset)
+            def stub(value: typing.Union[builtins.bool, cdktf.IResolvable]) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "inboundProxyProtocol", value)
 
@@ -618,7 +959,9 @@ class LoadbalancerFrontendPropertiesOutputReference(
     @timeout_client.setter
     def timeout_client(self, value: jsii.Number) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(LoadbalancerFrontendPropertiesOutputReference, "timeout_client").fset)
+            def stub(value: jsii.Number) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "timeoutClient", value)
 
@@ -633,7 +976,9 @@ class LoadbalancerFrontendPropertiesOutputReference(
         value: typing.Optional[LoadbalancerFrontendProperties],
     ) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(LoadbalancerFrontendPropertiesOutputReference, "internal_value").fset)
+            def stub(value: typing.Optional[LoadbalancerFrontendProperties]) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "internalValue", value)
 
@@ -641,6 +986,9 @@ class LoadbalancerFrontendPropertiesOutputReference(
 __all__ = [
     "LoadbalancerFrontend",
     "LoadbalancerFrontendConfig",
+    "LoadbalancerFrontendNetworks",
+    "LoadbalancerFrontendNetworksList",
+    "LoadbalancerFrontendNetworksOutputReference",
     "LoadbalancerFrontendProperties",
     "LoadbalancerFrontendPropertiesOutputReference",
 ]
