@@ -70,7 +70,28 @@ class LoadbalancerStaticBackendMember(
         :param provisioners: 
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(LoadbalancerStaticBackendMember.__init__)
+            def stub(
+                scope: constructs.Construct,
+                id_: builtins.str,
+                *,
+                backend: builtins.str,
+                ip: builtins.str,
+                max_sessions: jsii.Number,
+                name: builtins.str,
+                port: jsii.Number,
+                weight: jsii.Number,
+                enabled: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
+                id: typing.Optional[builtins.str] = None,
+                connection: typing.Optional[typing.Union[typing.Union[cdktf.SSHProvisionerConnection, typing.Dict[str, typing.Any]], typing.Union[cdktf.WinrmProvisionerConnection, typing.Dict[str, typing.Any]]]] = None,
+                count: typing.Optional[jsii.Number] = None,
+                depends_on: typing.Optional[typing.Sequence[cdktf.ITerraformDependable]] = None,
+                for_each: typing.Optional[cdktf.ITerraformIterator] = None,
+                lifecycle: typing.Optional[typing.Union[cdktf.TerraformResourceLifecycle, typing.Dict[str, typing.Any]]] = None,
+                provider: typing.Optional[cdktf.TerraformProvider] = None,
+                provisioners: typing.Optional[typing.Sequence[typing.Union[typing.Union[cdktf.FileProvisioner, typing.Dict[str, typing.Any]], typing.Union[cdktf.LocalExecProvisioner, typing.Dict[str, typing.Any]], typing.Union[cdktf.RemoteExecProvisioner, typing.Dict[str, typing.Any]]]]] = None,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
             check_type(argname="argument id_", value=id_, expected_type=type_hints["id_"])
         config = LoadbalancerStaticBackendMemberConfig(
@@ -160,7 +181,9 @@ class LoadbalancerStaticBackendMember(
     @backend.setter
     def backend(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(LoadbalancerStaticBackendMember, "backend").fset)
+            def stub(value: builtins.str) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "backend", value)
 
@@ -172,7 +195,9 @@ class LoadbalancerStaticBackendMember(
     @enabled.setter
     def enabled(self, value: typing.Union[builtins.bool, cdktf.IResolvable]) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(LoadbalancerStaticBackendMember, "enabled").fset)
+            def stub(value: typing.Union[builtins.bool, cdktf.IResolvable]) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "enabled", value)
 
@@ -184,7 +209,9 @@ class LoadbalancerStaticBackendMember(
     @id.setter
     def id(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(LoadbalancerStaticBackendMember, "id").fset)
+            def stub(value: builtins.str) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "id", value)
 
@@ -196,7 +223,9 @@ class LoadbalancerStaticBackendMember(
     @ip.setter
     def ip(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(LoadbalancerStaticBackendMember, "ip").fset)
+            def stub(value: builtins.str) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "ip", value)
 
@@ -208,7 +237,9 @@ class LoadbalancerStaticBackendMember(
     @max_sessions.setter
     def max_sessions(self, value: jsii.Number) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(LoadbalancerStaticBackendMember, "max_sessions").fset)
+            def stub(value: jsii.Number) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "maxSessions", value)
 
@@ -220,7 +251,9 @@ class LoadbalancerStaticBackendMember(
     @name.setter
     def name(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(LoadbalancerStaticBackendMember, "name").fset)
+            def stub(value: builtins.str) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "name", value)
 
@@ -232,7 +265,9 @@ class LoadbalancerStaticBackendMember(
     @port.setter
     def port(self, value: jsii.Number) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(LoadbalancerStaticBackendMember, "port").fset)
+            def stub(value: jsii.Number) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "port", value)
 
@@ -244,7 +279,9 @@ class LoadbalancerStaticBackendMember(
     @weight.setter
     def weight(self, value: jsii.Number) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(LoadbalancerStaticBackendMember, "weight").fset)
+            def stub(value: jsii.Number) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "weight", value)
 
@@ -310,7 +347,26 @@ class LoadbalancerStaticBackendMemberConfig(cdktf.TerraformMetaArguments):
         if isinstance(lifecycle, dict):
             lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
         if __debug__:
-            type_hints = typing.get_type_hints(LoadbalancerStaticBackendMemberConfig.__init__)
+            def stub(
+                *,
+                connection: typing.Optional[typing.Union[typing.Union[cdktf.SSHProvisionerConnection, typing.Dict[str, typing.Any]], typing.Union[cdktf.WinrmProvisionerConnection, typing.Dict[str, typing.Any]]]] = None,
+                count: typing.Optional[jsii.Number] = None,
+                depends_on: typing.Optional[typing.Sequence[cdktf.ITerraformDependable]] = None,
+                for_each: typing.Optional[cdktf.ITerraformIterator] = None,
+                lifecycle: typing.Optional[typing.Union[cdktf.TerraformResourceLifecycle, typing.Dict[str, typing.Any]]] = None,
+                provider: typing.Optional[cdktf.TerraformProvider] = None,
+                provisioners: typing.Optional[typing.Sequence[typing.Union[typing.Union[cdktf.FileProvisioner, typing.Dict[str, typing.Any]], typing.Union[cdktf.LocalExecProvisioner, typing.Dict[str, typing.Any]], typing.Union[cdktf.RemoteExecProvisioner, typing.Dict[str, typing.Any]]]]] = None,
+                backend: builtins.str,
+                ip: builtins.str,
+                max_sessions: jsii.Number,
+                name: builtins.str,
+                port: jsii.Number,
+                weight: jsii.Number,
+                enabled: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
+                id: typing.Optional[builtins.str] = None,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument connection", value=connection, expected_type=type_hints["connection"])
             check_type(argname="argument count", value=count, expected_type=type_hints["count"])
             check_type(argname="argument depends_on", value=depends_on, expected_type=type_hints["depends_on"])
