@@ -64,7 +64,25 @@ class Network(
         :param provisioners: 
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(Network.__init__)
+            def stub(
+                scope: constructs.Construct,
+                id_: builtins.str,
+                *,
+                ip_network: typing.Union[NetworkIpNetwork, typing.Dict[str, typing.Any]],
+                name: builtins.str,
+                zone: builtins.str,
+                id: typing.Optional[builtins.str] = None,
+                router: typing.Optional[builtins.str] = None,
+                connection: typing.Optional[typing.Union[typing.Union[cdktf.SSHProvisionerConnection, typing.Dict[str, typing.Any]], typing.Union[cdktf.WinrmProvisionerConnection, typing.Dict[str, typing.Any]]]] = None,
+                count: typing.Optional[jsii.Number] = None,
+                depends_on: typing.Optional[typing.Sequence[cdktf.ITerraformDependable]] = None,
+                for_each: typing.Optional[cdktf.ITerraformIterator] = None,
+                lifecycle: typing.Optional[typing.Union[cdktf.TerraformResourceLifecycle, typing.Dict[str, typing.Any]]] = None,
+                provider: typing.Optional[cdktf.TerraformProvider] = None,
+                provisioners: typing.Optional[typing.Sequence[typing.Union[typing.Union[cdktf.FileProvisioner, typing.Dict[str, typing.Any]], typing.Union[cdktf.LocalExecProvisioner, typing.Dict[str, typing.Any]], typing.Union[cdktf.RemoteExecProvisioner, typing.Dict[str, typing.Any]]]]] = None,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
             check_type(argname="argument id_", value=id_, expected_type=type_hints["id_"])
         config = NetworkConfig(
@@ -174,7 +192,9 @@ class Network(
     @id.setter
     def id(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(Network, "id").fset)
+            def stub(value: builtins.str) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "id", value)
 
@@ -186,7 +206,9 @@ class Network(
     @name.setter
     def name(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(Network, "name").fset)
+            def stub(value: builtins.str) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "name", value)
 
@@ -198,7 +220,9 @@ class Network(
     @router.setter
     def router(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(Network, "router").fset)
+            def stub(value: builtins.str) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "router", value)
 
@@ -210,7 +234,9 @@ class Network(
     @zone.setter
     def zone(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(Network, "zone").fset)
+            def stub(value: builtins.str) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "zone", value)
 
@@ -269,7 +295,23 @@ class NetworkConfig(cdktf.TerraformMetaArguments):
         if isinstance(ip_network, dict):
             ip_network = NetworkIpNetwork(**ip_network)
         if __debug__:
-            type_hints = typing.get_type_hints(NetworkConfig.__init__)
+            def stub(
+                *,
+                connection: typing.Optional[typing.Union[typing.Union[cdktf.SSHProvisionerConnection, typing.Dict[str, typing.Any]], typing.Union[cdktf.WinrmProvisionerConnection, typing.Dict[str, typing.Any]]]] = None,
+                count: typing.Optional[jsii.Number] = None,
+                depends_on: typing.Optional[typing.Sequence[cdktf.ITerraformDependable]] = None,
+                for_each: typing.Optional[cdktf.ITerraformIterator] = None,
+                lifecycle: typing.Optional[typing.Union[cdktf.TerraformResourceLifecycle, typing.Dict[str, typing.Any]]] = None,
+                provider: typing.Optional[cdktf.TerraformProvider] = None,
+                provisioners: typing.Optional[typing.Sequence[typing.Union[typing.Union[cdktf.FileProvisioner, typing.Dict[str, typing.Any]], typing.Union[cdktf.LocalExecProvisioner, typing.Dict[str, typing.Any]], typing.Union[cdktf.RemoteExecProvisioner, typing.Dict[str, typing.Any]]]]] = None,
+                ip_network: typing.Union[NetworkIpNetwork, typing.Dict[str, typing.Any]],
+                name: builtins.str,
+                zone: builtins.str,
+                id: typing.Optional[builtins.str] = None,
+                router: typing.Optional[builtins.str] = None,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument connection", value=connection, expected_type=type_hints["connection"])
             check_type(argname="argument count", value=count, expected_type=type_hints["count"])
             check_type(argname="argument depends_on", value=depends_on, expected_type=type_hints["depends_on"])
@@ -459,7 +501,17 @@ class NetworkIpNetwork:
         :param gateway: Gateway address given by DHCP. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/upcloud/r/network#gateway Network#gateway}
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(NetworkIpNetwork.__init__)
+            def stub(
+                *,
+                address: builtins.str,
+                dhcp: typing.Union[builtins.bool, cdktf.IResolvable],
+                family: builtins.str,
+                dhcp_default_route: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
+                dhcp_dns: typing.Optional[typing.Sequence[builtins.str]] = None,
+                gateway: typing.Optional[builtins.str] = None,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument address", value=address, expected_type=type_hints["address"])
             check_type(argname="argument dhcp", value=dhcp, expected_type=type_hints["dhcp"])
             check_type(argname="argument family", value=family, expected_type=type_hints["family"])
@@ -564,7 +616,12 @@ class NetworkIpNetworkOutputReference(
         :param terraform_attribute: The attribute on the parent resource this class is referencing.
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(NetworkIpNetworkOutputReference.__init__)
+            def stub(
+                terraform_resource: cdktf.IInterpolatingParent,
+                terraform_attribute: builtins.str,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
             check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
         jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])
@@ -623,7 +680,9 @@ class NetworkIpNetworkOutputReference(
     @address.setter
     def address(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(NetworkIpNetworkOutputReference, "address").fset)
+            def stub(value: builtins.str) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "address", value)
 
@@ -635,7 +694,9 @@ class NetworkIpNetworkOutputReference(
     @dhcp.setter
     def dhcp(self, value: typing.Union[builtins.bool, cdktf.IResolvable]) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(NetworkIpNetworkOutputReference, "dhcp").fset)
+            def stub(value: typing.Union[builtins.bool, cdktf.IResolvable]) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "dhcp", value)
 
@@ -650,7 +711,9 @@ class NetworkIpNetworkOutputReference(
         value: typing.Union[builtins.bool, cdktf.IResolvable],
     ) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(NetworkIpNetworkOutputReference, "dhcp_default_route").fset)
+            def stub(value: typing.Union[builtins.bool, cdktf.IResolvable]) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "dhcpDefaultRoute", value)
 
@@ -662,7 +725,9 @@ class NetworkIpNetworkOutputReference(
     @dhcp_dns.setter
     def dhcp_dns(self, value: typing.List[builtins.str]) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(NetworkIpNetworkOutputReference, "dhcp_dns").fset)
+            def stub(value: typing.List[builtins.str]) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "dhcpDns", value)
 
@@ -674,7 +739,9 @@ class NetworkIpNetworkOutputReference(
     @family.setter
     def family(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(NetworkIpNetworkOutputReference, "family").fset)
+            def stub(value: builtins.str) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "family", value)
 
@@ -686,7 +753,9 @@ class NetworkIpNetworkOutputReference(
     @gateway.setter
     def gateway(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(NetworkIpNetworkOutputReference, "gateway").fset)
+            def stub(value: builtins.str) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "gateway", value)
 
@@ -698,7 +767,9 @@ class NetworkIpNetworkOutputReference(
     @internal_value.setter
     def internal_value(self, value: typing.Optional[NetworkIpNetwork]) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(NetworkIpNetworkOutputReference, "internal_value").fset)
+            def stub(value: typing.Optional[NetworkIpNetwork]) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "internalValue", value)
 
